@@ -1,11 +1,11 @@
-# Copyright 2021 Q-CTRL. All rights reserved.
+# Copyright 2022 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
 # Proprietary and confidential. You may not use this file except in compliance
 # with the License. You may obtain a copy of the License at
 #
-#     https://q-ctrl.com/terms
+#    https://q-ctrl.com/terms
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS. See the
@@ -14,7 +14,6 @@
 import logging
 import os
 import sys
-import warnings
 import webbrowser
 from threading import Thread
 from typing import (
@@ -63,14 +62,6 @@ from .utils import (
 
 LOGGER = logging.getLogger(__name__)
 
-warnings.formatwarning = lambda message, *args, **kwargs: f"{message}\n"
-if sys.version_info.minor < 7:
-    warnings.warn(
-        "You are currently running with Python 3.6. "
-        "Support of Python 3.6 will be dropped in April 2022 "
-        "since it has reached end-of-life in December 2021.",
-    )
-
 
 class Qctrl:
     """A mediator class. Used to authenticate with Q-CTRL and access Q-CTRL features.
@@ -214,12 +205,7 @@ class Qctrl:
         """
 
         query = ActivityMonitorQuery(self.gql_api)
-        query(
-            limit=limit,
-            offset=offset,
-            status=status,
-            action_type=action_type,
-        )
+        query(limit=limit, offset=offset, status=status, action_type=action_type)
 
     def get_result(
         self, action_id: Union[str, int]
@@ -353,10 +339,7 @@ class Qctrl:
     stop=tenacity.stop_after_attempt(3),
     retry=tenacity.retry_if_exception_type((RequestException, BaseHTTPError)),
 )
-def _build_client(
-    api_root: str,
-    oidc_url: str,
-) -> Client:
+def _build_client(api_root: str, oidc_url: str) -> Client:
     """
     Builds an authenticated GraphQL client and validates its authentication.
 
@@ -397,6 +380,4 @@ def _build_client(
     return client
 
 
-__all__ = [
-    "Qctrl",
-]
+__all__ = ["Qctrl"]
